@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 13059 2021-07-13 07:55:50Z Mint $
+# $Id: urls.py 13075 2021-07-16 07:48:34Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Mint $
-# $Date: 2021-07-13 15:55:50 +0800 (週二, 13 七月 2021) $
-# $Revision: 13059 $ 
+# $Date: 2021-07-16 15:48:34 +0800 (週五, 16 七月 2021) $
+# $Revision: 13075 $ 
 
 from django.conf.urls import url
 from django.urls import include, path
@@ -26,5 +26,5 @@ urlpatterns = [
     url(r'^comments/add$', views.CommentView.as_view(), name='addComment'),
     url(r'^comments/(?P<pk>\d+)/hide$', 
         views.CommentHideView.as_view(), name='hideComment'),
-    path('captcha/', include('captcha.urls')),        
+    path('captcha/$', include('captcha.urls')),        
 ]
